@@ -14,33 +14,33 @@
 
 #include <QString>
 
-namespace Okular {
-
+namespace Okular
+{
 class Action;
 class FormField;
 
 class FormFieldPrivate
 {
-    public:
-        explicit FormFieldPrivate( FormField::FieldType type );
-        virtual ~FormFieldPrivate();
+public:
+    explicit FormFieldPrivate(FormField::FieldType type);
+    virtual ~FormFieldPrivate();
 
-        FormFieldPrivate(const FormFieldPrivate &) = delete;
-        FormFieldPrivate  &operator=(const FormFieldPrivate &) = delete;
+    FormFieldPrivate(const FormFieldPrivate &) = delete;
+    FormFieldPrivate &operator=(const FormFieldPrivate &) = delete;
 
-        void setDefault();
+    void setDefault();
 
-        virtual void setValue( const QString& ) = 0;
-        virtual QString value() const = 0;
+    virtual void setValue(const QString &) = 0;
+    virtual QString value() const = 0;
 
-        FormField::FieldType m_type;
-        QString m_default;
-        Action *m_activateAction;
-        QHash<int, Action*> m_additionalActions;
-        QHash<int, Action*> m_additionalAnnotActions;
+    FormField::FieldType m_type;
+    QString m_default;
+    Action *m_activateAction;
+    QHash<int, Action *> m_additionalActions;
+    QHash<int, Action *> m_additionalAnnotActions;
 
-        Q_DECLARE_PUBLIC( FormField )
-        FormField *q_ptr;
+    Q_DECLARE_PUBLIC(FormField)
+    FormField *q_ptr;
 };
 
 }
