@@ -29,7 +29,6 @@
 #include "action.h"
 #include "annotations.h"
 #include "annotations_p.h"
-#include "area.h"
 #include "debug_p.h"
 #include "document.h"
 #include "document_p.h"
@@ -40,7 +39,6 @@
 #include "pagesize.h"
 #include "pagetransition.h"
 #include "rotationjob_p.h"
-#include "textpage.h"
 #include "textpage_p.h"
 #include "tile.h"
 #include "tilesmanager_p.h"
