@@ -17,17 +17,16 @@
 
 #include <QLoggingCategory>
 #if defined(WITH_KPTY)
-#include <KPty/kptyprocess.h>
 #include <KPty/kptydevice.h>
+#include <KPty/kptyprocess.h>
 #endif
 
 #include "debug_comicbook.h"
 
-#include <memory>
 #include <QStandardPaths>
+#include <memory>
 
-struct UnrarHelper
-{
+struct UnrarHelper {
     UnrarHelper();
     ~UnrarHelper();
 
@@ -39,62 +38,57 @@ struct UnrarHelper
     QString lsarPath;
 };
 
-Q_GLOBAL_STATIC( UnrarHelper, helper )
+Q_GLOBAL_STATIC(UnrarHelper, helper)
 
-static UnrarFlavour* detectUnrar( const QString &unrarPath, const QString &versionCommand )
+static UnrarFlavour *detectUnrar(const QString &unrarPath, const QString &versionCommand)
 {
-    UnrarFlavour* kind = nullptr;
+    UnrarFlavour *kind = nullptr;
     QProcess proc;
-    proc.start( unrarPath, QStringList() << versionCommand );
-    bool ok = proc.waitForFinished( -1 );
-    Q_UNUSED( ok )
-    const QStringList lines = QString::fromLocal8Bit( proc.readAllStandardOutput() ).split( QLatin1Char('\n'), QString::SkipEmptyParts );
-    if ( !lines.isEmpty() )
-    {
-        if ( lines.first().startsWith( QLatin1String("UNRAR ") ) )
+    proc.start(unrarPath, QStringList() << versionCommand);
+    bool ok = proc.waitForFinished(-1);
+    Q_UNUSED(ok)
+    const QStringList lines = QString::fromLocal8Bit(proc.readAllStandardOutput()).split(QLatin1Char('\n'), QString::SkipEmptyParts);
+    if (!lines.isEmpty()) {
+        if (lines.first().startsWith(QLatin1String("UNRAR ")))
             kind = new NonFreeUnrarFlavour();
-        else if ( lines.first().startsWith( QLatin1String("RAR ") ) )
+        else if (lines.first().startsWith(QLatin1String("RAR ")))
             kind = new NonFreeUnrarFlavour();
-        else if ( lines.first().startsWith( QLatin1String("unrar ") ) )
+        else if (lines.first().startsWith(QLatin1String("unrar ")))
             kind = new FreeUnrarFlavour();
-        else if ( lines.first().startsWith( QLatin1String("v") ) )
+        else if (lines.first().startsWith(QLatin1String("v")))
             kind = new UnarFlavour();
     }
     return kind;
 }
 
 UnrarHelper::UnrarHelper()
-   : kind( nullptr )
+    : kind(nullptr)
 {
-    QString path = QStandardPaths::findExecutable( QStringLiteral("lsar") );
+    QString path = QStandardPaths::findExecutable(QStringLiteral("lsar"));
 
-    if ( !path.isEmpty() )
-    {
+    if (!path.isEmpty()) {
         lsarPath = path;
     }
 
-    path = QStandardPaths::findExecutable( QStringLiteral("unrar-nonfree") );
+    path = QStandardPaths::findExecutable(QStringLiteral("unrar-nonfree"));
 
-    if ( path.isEmpty() )
-        path = QStandardPaths::findExecutable( QStringLiteral("unrar") );
-    if ( path.isEmpty() )
-        path = QStandardPaths::findExecutable( QStringLiteral("rar") );
-    if ( path.isEmpty() )
-        path = QStandardPaths::findExecutable( QStringLiteral("unar") );
+    if (path.isEmpty())
+        path = QStandardPaths::findExecutable(QStringLiteral("unrar"));
+    if (path.isEmpty())
+        path = QStandardPaths::findExecutable(QStringLiteral("rar"));
+    if (path.isEmpty())
+        path = QStandardPaths::findExecutable(QStringLiteral("unar"));
 
-    if ( !path.isEmpty() )
-        kind = detectUnrar( path, QStringLiteral("--version") );
+    if (!path.isEmpty())
+        kind = detectUnrar(path, QStringLiteral("--version"));
 
-    if ( !kind )
-        kind = detectUnrar( path, QStringLiteral("-v") );
+    if (!kind)
+        kind = detectUnrar(path, QStringLiteral("-v"));
 
-    if ( !kind )
-    {
+    if (!kind) {
         // no luck, print that
         qWarning() << "Neither unrar nor unarchiver were found.";
-    }
-    else
-    {
+    } else {
         unrarPath = path;
         qCDebug(OkularComicbookDebug) << "detected:" << path << "(" << kind->name() << ")";
     }
@@ -105,9 +99,10 @@ UnrarHelper::~UnrarHelper()
     delete kind;
 }
 
-
 Unrar::Unrar()
-    : QObject( nullptr ), mLoop( nullptr ), mTempDir( nullptr )
+    : QObject(nullptr)
+    , mLoop(nullptr)
+    , mTempDir(nullptr)
 {
 }
 
@@ -116,9 +111,9 @@ Unrar::~Unrar()
     delete mTempDir;
 }
 
-bool Unrar::open( const QString &fileName )
+bool Unrar::open(const QString &fileName)
 {
-    if ( !isSuitableVersionAvailable() )
+    if (!isSuitableVersionAvailable())
         return false;
 
     delete mTempDir;
@@ -132,7 +127,7 @@ bool Unrar::open( const QString &fileName )
     mStdOutData.clear();
     mStdErrData.clear();
 
-    const int ret = startSyncProcess( helper->kind->processOpenArchiveArgs( mFileName, mTempDir->path() ) );
+    const int ret = startSyncProcess(helper->kind->processOpenArchiveArgs(mFileName, mTempDir->path()));
     bool ok = ret == 0;
 
     return ok;
@@ -143,52 +138,52 @@ QStringList Unrar::list()
     mStdOutData.clear();
     mStdErrData.clear();
 
-    if ( !isSuitableVersionAvailable() )
+    if (!isSuitableVersionAvailable())
         return QStringList();
 
-    startSyncProcess( helper->kind->processListArgs( mFileName ) );
+    startSyncProcess(helper->kind->processListArgs(mFileName));
 
-    QStringList listFiles = helper->kind->processListing( QString::fromLocal8Bit( mStdOutData ).split( QLatin1Char('\n'), QString::SkipEmptyParts ) );
+    QStringList listFiles = helper->kind->processListing(QString::fromLocal8Bit(mStdOutData).split(QLatin1Char('\n'), QString::SkipEmptyParts));
 
     QString subDir;
 
-    if ( listFiles.last().endsWith( QLatin1Char('/') ) && helper->kind->name() == QLatin1String("unar") ) {
+    if (listFiles.last().endsWith(QLatin1Char('/')) && helper->kind->name() == QLatin1String("unar")) {
         // Subfolder detected. The unarchiver is unable to extract all files into a single folder
         subDir = listFiles.last();
         listFiles.removeLast();
     }
 
     QStringList newList;
-    for ( const QString &f : qAsConst(listFiles) ) {
+    for (const QString &f : qAsConst(listFiles)) {
         // Extract all the files to mTempDir regardless of their path inside the archive
         // This will break if ever an arvhice with two files with the same name in different subfolders
-        QFileInfo fi( f );
-        if ( QFile::exists( mTempDir->path() + QLatin1Char('/') + subDir + fi.fileName() ) ) {
-            newList.append( subDir + fi.fileName() );
+        QFileInfo fi(f);
+        if (QFile::exists(mTempDir->path() + QLatin1Char('/') + subDir + fi.fileName())) {
+            newList.append(subDir + fi.fileName());
         }
     }
     return newList;
 }
 
-QByteArray Unrar::contentOf( const QString &fileName ) const
+QByteArray Unrar::contentOf(const QString &fileName) const
 {
-    if ( !isSuitableVersionAvailable() )
+    if (!isSuitableVersionAvailable())
         return QByteArray();
 
-    QFile file( mTempDir->path() + QLatin1Char('/') + fileName );
-    if ( !file.open( QIODevice::ReadOnly ) )
+    QFile file(mTempDir->path() + QLatin1Char('/') + fileName);
+    if (!file.open(QIODevice::ReadOnly))
         return QByteArray();
 
     return file.readAll();
 }
 
-QIODevice* Unrar::createDevice( const QString &fileName ) const
+QIODevice *Unrar::createDevice(const QString &fileName) const
 {
-    if ( !isSuitableVersionAvailable() )
+    if (!isSuitableVersionAvailable())
         return nullptr;
 
-    std::unique_ptr< QFile> file( new QFile( mTempDir->path() + QLatin1Char('/') + fileName ) );
-    if ( !file->open( QIODevice::ReadOnly ) )
+    std::unique_ptr<QFile> file(new QFile(mTempDir->path() + QLatin1Char('/') + fileName));
+    if (!file->open(QIODevice::ReadOnly))
         return nullptr;
 
     return file.release();
@@ -201,10 +196,10 @@ bool Unrar::isAvailable()
 
 bool Unrar::isSuitableVersionAvailable()
 {
-    if ( !isAvailable() )
+    if (!isAvailable())
         return false;
 
-    if (dynamic_cast< NonFreeUnrarFlavour * >( helper->kind ) || dynamic_cast< UnarFlavour * >( helper->kind ))
+    if (dynamic_cast<NonFreeUnrarFlavour *>(helper->kind) || dynamic_cast<UnarFlavour *>(helper->kind))
         return true;
     else
         return false;
@@ -212,7 +207,7 @@ bool Unrar::isSuitableVersionAvailable()
 
 void Unrar::readFromStdout()
 {
-    if ( !mProcess )
+    if (!mProcess)
         return;
 
     mStdOutData += mProcess->readAllStandardOutput();
@@ -220,39 +215,37 @@ void Unrar::readFromStdout()
 
 void Unrar::readFromStderr()
 {
-    if ( !mProcess )
+    if (!mProcess)
         return;
 
     mStdErrData += mProcess->readAllStandardError();
-    if ( !mStdErrData.isEmpty() )
-    {
+    if (!mStdErrData.isEmpty()) {
         mProcess->kill();
         return;
     }
 }
 
-void Unrar::finished( int exitCode, QProcess::ExitStatus exitStatus )
+void Unrar::finished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    Q_UNUSED( exitCode )
-    if ( mLoop )
-    {
-        mLoop->exit( exitStatus == QProcess::CrashExit ? 1 : 0 );
+    Q_UNUSED(exitCode)
+    if (mLoop) {
+        mLoop->exit(exitStatus == QProcess::CrashExit ? 1 : 0);
     }
 }
 
-int Unrar::startSyncProcess( const ProcessArgs &args )
+int Unrar::startSyncProcess(const ProcessArgs &args)
 {
     int ret = 0;
 
 #if !defined(WITH_KPTY)
-    mProcess = new QProcess( this );    
+    mProcess = new QProcess(this);
     connect(mProcess, &QProcess::readyReadStandardOutput, this, &Unrar::readFromStdout);
     connect(mProcess, &QProcess::readyReadStandardError, this, &Unrar::readFromStderr);
     connect(mProcess, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &Unrar::finished);
 
 #else
-    mProcess = new KPtyProcess( this );
-    mProcess->setOutputChannelMode( KProcess::SeparateChannels );    
+    mProcess = new KPtyProcess(this);
+    mProcess->setOutputChannelMode(KProcess::SeparateChannels);
     connect(mProcess, &KPtyProcess::readyReadStandardOutput, this, &Unrar::readFromStdout);
     connect(mProcess, &KPtyProcess::readyReadStandardError, this, &Unrar::readFromStderr);
     connect(mProcess, static_cast<void (KPtyProcess::*)(int, QProcess::ExitStatus)>(&KPtyProcess::finished), this, &Unrar::finished);
@@ -260,31 +253,25 @@ int Unrar::startSyncProcess( const ProcessArgs &args )
 #endif
 
 #if !defined(WITH_KPTY)
-    if ( helper->kind->name() == QLatin1String( "unar" ) && args.useLsar )
-    {
-        mProcess->start( helper->lsarPath, args.appArgs, QIODevice::ReadWrite | QIODevice::Unbuffered );
-    }
-    else
-    {
-        mProcess->start( helper->unrarPath, args.appArgs, QIODevice::ReadWrite | QIODevice::Unbuffered );
+    if (helper->kind->name() == QLatin1String("unar") && args.useLsar) {
+        mProcess->start(helper->lsarPath, args.appArgs, QIODevice::ReadWrite | QIODevice::Unbuffered);
+    } else {
+        mProcess->start(helper->unrarPath, args.appArgs, QIODevice::ReadWrite | QIODevice::Unbuffered);
     }
 
-    ret = mProcess->waitForFinished( -1 ) ? 0 : 1;
+    ret = mProcess->waitForFinished(-1) ? 0 : 1;
 #else
-    if ( helper->kind->name() == QLatin1String( "unar" ) && args.useLsar )
-    {
-        mProcess->setProgram( helper->lsarPath, args.appArgs );
-    }
-    else
-    {
-        mProcess->setProgram( helper->unrarPath, args.appArgs );
+    if (helper->kind->name() == QLatin1String("unar") && args.useLsar) {
+        mProcess->setProgram(helper->lsarPath, args.appArgs);
+    } else {
+        mProcess->setProgram(helper->unrarPath, args.appArgs);
     }
 
-    mProcess->setNextOpenMode( QIODevice::ReadWrite | QIODevice::Unbuffered );
+    mProcess->setNextOpenMode(QIODevice::ReadWrite | QIODevice::Unbuffered);
     mProcess->start();
     QEventLoop loop;
     mLoop = &loop;
-    ret = loop.exec( QEventLoop::WaitForMoreEvents | QEventLoop::ExcludeUserInputEvents );
+    ret = loop.exec(QEventLoop::WaitForMoreEvents | QEventLoop::ExcludeUserInputEvents);
     mLoop = nullptr;
 #endif
 
@@ -294,15 +281,14 @@ int Unrar::startSyncProcess( const ProcessArgs &args )
     return ret;
 }
 
-void Unrar::writeToProcess( const QByteArray &data )
+void Unrar::writeToProcess(const QByteArray &data)
 {
-    if ( !mProcess || data.isNull() )
+    if (!mProcess || data.isNull())
         return;
 
 #if !defined(WITH_KPTY)
-    mProcess->write( data );
+    mProcess->write(data);
 #else
-    mProcess->pty()->write( data );
+    mProcess->pty()->write(data);
 #endif
 }
-
