@@ -40,12 +40,11 @@
 #include <KXMLGUIFactory>
 #include <QApplication>
 #include <QDBusConnection>
-#include <QDesktopWidget>
 #include <QDragMoveEvent>
 #include <QFileDialog>
 #include <QMenuBar>
-#include <QMimeDatabase>
-#include <QMimeType>
+#include <QObject>
+#include <QScreen>
 #include <QTabBar>
 #include <QTabWidget>
 #include <QTimer>
@@ -53,6 +52,8 @@
 #include <KActivities/ResourceInstance>
 #endif
 
+#include <kio_version.h>
+
 // local includes
 #include "../interfaces/viewerinterface.h"
 #include "kdocumentviewer.h"
@@ -213,7 +214,7 @@ bool Shell::openDocument(const QUrl &url, const QString &serializedOptions)
     KParts::ReadWritePart *const part = m_tabs[0].part;
 
     // Return false if we can't open new tabs and the only part is occupied
-    if (!dynamic_cast<Okular::ViewerInterface *>(part)->openNewFilesInTabs() && !part->url().isEmpty() && !ShellUtils::unique(serializedOptions)) {
+    if (!qobject_cast<Okular::ViewerInterface *>(part)->openNewFilesInTabs() && !part->url().isEmpty() && !ShellUtils::unique(serializedOptions)) {
         return false;
     }
 
@@ -233,7 +234,7 @@ bool Shell::canOpenDocs(int numDocs, int desktop)
         return false;
 
     KParts::ReadWritePart *const part = m_tabs[0].part;
-    const bool allowTabs = dynamic_cast<Okular::ViewerInterface *>(part)->openNewFilesInTabs();
+    const bool allowTabs = qobject_cast<Okular::ViewerInterface *>(part)->openNewFilesInTabs();
 
     if (!allowTabs && (numDocs > 1 || !part->url().isEmpty()))
         return false;
@@ -255,7 +256,7 @@ void Shell::openUrl(const QUrl &url, const QString &serializedOptions)
                 applyOptionsToPart(activePart, serializedOptions);
                 activePart->openUrl(url);
             } else {
-                if (dynamic_cast<Okular::ViewerInterface *>(activePart)->openNewFilesInTabs()) {
+                if (qobject_cast<Okular::ViewerInterface *>(activePart)->openNewFilesInTabs()) {
                     openNewTab(url, serializedOptions);
                 } else {
                     Shell *newShell = new Shell(serializedOptions);
@@ -289,6 +290,18 @@ void Shell::openUrl(const QUrl &url, const QString &serializedOptions)
 void Shell::closeUrl()
 {
     closeTab(m_tabWidget->currentIndex());
+
+    // When closing the current tab two things can happen:
+    //  * the focus was on the tab
+    //  * the focus was somewhere in the toolbar
+    // we don't have other places that accept focus
+    //  * If it was on the tab, logic says it should go back to the next current tab
+    //  * If it was on the toolbar, we could leave it there, but since we redo the menus/toobars for the new tab, it gets kind of lost
+    //    so it's easier to set it to the next current tab which also makes sense as consistency
+    if (m_tabWidget->count() >= 0) {
+        KParts::ReadWritePart *const newPart = m_tabs[m_tabWidget->currentIndex()].part;
+        newPart->widget()->setFocus();
+    }
 }
 
 void Shell::readSettings()
@@ -433,6 +446,15 @@ void Shell::fileOpen()
     dlg->setFileMode(QFileDialog::ExistingFiles); // Allow selection of more than one file
 
     QMimeDatabase mimeDatabase;
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 73, 0)
+    QStringList mimetypes;
+    for (const QString &mimeName : qAsConst(m_fileformats)) {
+        QMimeType mimeType = mimeDatabase.mimeTypeForName(mimeName);
+        mimetypes << mimeType.name();
+    }
+    mimetypes << QStringLiteral("application/octet-stream");
+    dlg->setMimeTypeFilters(mimetypes);
+#else
     QSet<QString> globPatterns;
     QMap<QString, QStringList> namedGlobs;
     for (const QString &mimeName : qAsConst(m_fileformats)) {
@@ -442,7 +464,11 @@ void Shell::fileOpen()
             continue;
         }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        globPatterns.unite(QSet<QString>(globs.begin(), globs.end()));
+#else
         globPatterns.unite(globs.toSet());
+#endif
 
         namedGlobs[mimeType.comment()].append(globs);
     }
@@ -455,6 +481,7 @@ void Shell::fileOpen()
     namePatterns.prepend(i18n("All files (*)"));
     namePatterns.prepend(i18n("All supported files (%1)", allGlobPatterns.join(QLatin1Char(' '))));
     dlg->setNameFilters(namePatterns);
+#endif
 
     dlg->setWindowTitle(i18n("Open Document"));
     if (dlg->exec() && dlg) {
@@ -543,7 +570,7 @@ void Shell::slotShowMenubar()
 
 QSize Shell::sizeHint() const
 {
-    return QApplication::desktop()->availableGeometry(this).size() * 0.75;
+    return QApplication::primaryScreen()->availableSize() * 0.75;
 }
 
 bool Shell::queryClose()
